<?php

declare(strict_types=1);

namespace apexl\Io\modules\jobs\Request;

use apexl\Io\Request\IoRequest;

class QueueProcessRequest extends IoRequest
{
    public function limit(): ?int
    {
        return $this->bodyParam('limit');
    }
}
