<?php

declare(strict_types=1);

namespace apexl\Io\modules\jobs\Interface;

use Throwable;

interface QueueTaskHandlerInterface
{
    /**
     * @throws Throwable
     */
    public function run(): void;

    public function handleFailure(string $task, Throwable $throwable): void;
}
