<?php

declare(strict_types=1);

use apexl\Io\modules\jobs\Interface\QueuedTaskFinderInterface;
use apexl\Io\modules\jobs\Service\QueuedTaskFinderDb;
use function DI\autowire;

return [
    QueuedTaskFinderInterface::class => autowire(QueuedTaskFinderDb::class),
];
