<?php

declare(strict_types=1);

return [
    'streams' => [
        "queue" => [
            "level" => env('LOG__QUEUE_LEVEL'),
            "handlers" => [
                [
                    "destination" => "file"
                ]
            ]
        ],
    ],
];